<?php
/**
 * Outset functions and definitions.
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * @package WordPress
 * @subpackage Outset
 */

/** Tell WordPress to run outset_setup() when the 'after_setup_theme' hook is run. */
add_action( 'after_setup_theme', 'outset_setup' );

if ( ! function_exists( 'outset_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @uses add_theme_support() To add support for post thumbnails and automatic feed links.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses add_custom_background() To add support for a custom background.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 */
function outset_setup() {

	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Navigation', 'outset' ),
	) );

	// This theme allows users to set a custom background
	add_custom_background();

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be 600 pixels wide by 600 pixels tall.
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( 800, 800, true );
	
	// Register features
	require_once(TEMPLATEPATH . '/library/includes/custom_functions.php');
	
	// Remove some defaults
	remove_action('wp_head', 'start_post_rel_link');
	remove_action('wp_head', 'index_rel_link');
	remove_action('wp_head', 'adjacent_posts_rel_link');
	remove_action('wp_head', 'next_post_rel_link');
	remove_action('wp_head', 'previous_post_rel_link');
}
endif;

/**
 * Set Theme Info in Constant
 *
 * @return
 */
$themeData = get_theme_data(TEMPLATEPATH . '/style.css');
$version = trim($themeData['Version']);
if(!$version)
	$version = "unknown";
	
define('THEMENAME', $themeData['Title']);
define('THEMEVERSION', $version);

/**
 * Replace WP version to Theme version.
 *
 * @return string "generator" meta tag
 */
function outset_wp_generator()
{
	echo '<meta name="generator" content="'.THEMENAME." ".THEMEVERSION.'" />';
}
add_filter('the_generator','outset_wp_generator');

/**
 * SEO: Create meta data tags.
 *
 * @retun string "description" meta tag
 * @retun string "keywords" meta tag
 * @retun string "author" meta tag
 */
function outset_create_metadata() {
	if(is_home()) {
		if ( outset_getoption('meta_description') <> "" ) { echo '<meta name="description" content="'.stripslashes(outset_getoption('meta_description')).'" />' . "\n"; }
		if ( outset_getoption('meta_keywords') <> "" ) { echo '<meta name="keywords" content="'.stripslashes(outset_getoption('meta_keywords')).'" />' . "\n"; }
		if ( outset_getoption('meta_author') <> "" ) { echo '<meta name="author" content="'.stripslashes(outset_getoption('meta_author')).'" />' . "\n"; }
	}
}

/**
 * SEO: Create robots.
 *
 * @return string "robots" meta tag
 */
function outset_create_robots() {
	global $paged;

	if((is_home() && ($paged < 2 )) || is_front_page() || is_single() || is_page() || is_attachment()) {
		$content .= "<meta name=\"robots\" content=\"index,follow\" />";
	} elseif (is_search()) {
		$content .= "<meta name=\"robots\" content=\"noindex,nofollow\" />";
	} else {	
		$content .= "<meta name=\"robots\" content=\"noindex,follow\" />";
	}
	$content .= "\n";
	if (get_option('blog_public')) {
		echo apply_filters('outset_create_robots', $content);
	}
}
 
/**
 * SEO: Create canonical url.
 *
 * @return string "canonical" link
 */
function outset_canonical_url() {
	if(outset_getoption("canonical_url") == "yes") {
		if ( is_singular() ) {
			$canonical_url .= '<link rel="canonical" href="' . get_permalink() . '" />';
			$canonical_url .= "\n";        
			echo apply_filters('outset_canonical_url', $canonical_url);
		}
	}
}

/**
 * Load required javascript to wp_head().
 */
function outset_header_scripts() {
	$scriptdir_start .= '<script type="text/javascript" src="';
	$scriptdir_start .= get_bloginfo('template_directory');
	$scriptdir_start .= '/library/scripts/';
	$scriptdir_end = '"></script>';
	$scripts .= $scriptdir_start . 'jquery.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'hoverIntent.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'superfish.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'supersubs.js' . $scriptdir_end . "\n";
	$dropdown_options = $scriptdir_start . 'dropdowns.js' . $scriptdir_end . "\n";
	$scripts = $scripts . apply_filters('dropdown_options', $dropdown_options);
	$scripts .= $scriptdir_start . 'slider.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'shortcodes.js' . $scriptdir_end . "\n";
	$scripts .= $scriptdir_start . 'nivo-slider.js' . $scriptdir_end . "\n";
	
	// Inset custom header script - via theme option
	if(outset_getoption("load_header_scripts") == "yes") {
		$scripts .= outset_getoption("header_scripts_code") . "\n";
	}
	
	// Print filtered scripts
	print apply_filters('outset_header_scripts', $scripts);
	
}
add_action('wp_head','outset_header_scripts');

/**
 * Inset custom footer script to wp_footer().
 */
function outset_footer_scripts() {
	if(outset_getoption("load_footer_scripts") == "yes") {
		$scripts .= outset_getoption('footer_scripts_code');
	}
	
	// Print filtered scripts
	print apply_filters('outset_footer_scripts', $scripts);
}
add_action('wp_footer','outset_footer_scripts');

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function outset_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'outset_page_menu_args' );

/**
 * Add ID and CLASS attributes to the first <ul> occurence in wp_page_menu.
 */
function outset_add_menuclass($ulclass) {
	return preg_replace('/<ul>/', '<ul class="sf-menu">', $ulclass, 1);
}
add_filter('wp_page_menu','outset_add_menuclass');

/**
 * Add the proper class of menu container if wp_nav_menu is not set.
 */
function outset_proper_containerclass($containerclass) {
	return preg_replace('/<div class="sf-menu">/', '<div class="menu">', $containerclass, 1);
}
add_filter('wp_page_menu','outset_proper_containerclass');

/**
 * Sets the post excerpt length to 40 characters.
 *
 * @return int
 */
function outset_excerpt_length( $length ) {
	return 30;
}
add_filter( 'excerpt_length', 'outset_excerpt_length' );

/**
 * Returns a "Continue Reading" link for excerpts
 *
 * @return string "Continue Reading" link
 */
function outset_continue_reading_link() {
	return ' <a class="readmore" href="'. get_permalink() . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'outset' ) . '</a>';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and outset_continue_reading_link().
 *
 * @return string An ellipsis
 */
function outset_auto_excerpt_more( $more ) {
	return ' &hellip;' . outset_continue_reading_link();
}
add_filter( 'excerpt_more', 'outset_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * @return string Excerpt with a pretty "Continue Reading" link
 */
function outset_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= outset_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'outset_custom_excerpt_more' );

/**
 * Remove inline styles printed when the gallery shortcode is used.
 *
 * @return string The gallery style filter, with the styles themselves removed.
 */
function outset_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}
add_filter( 'gallery_style', 'outset_remove_gallery_css' );

if ( ! function_exists( 'outset_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker without modifying the comments template
 * simply create your own outset_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function outset_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch($comment->comment_type){
		case '':
?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
    	<div id="comment-<?php comment_ID(); ?>">
            <div class="comment_meta commentmetadata">
                <span class="avatar alignleft"><?php echo get_avatar( $comment, 40 ); ?></span>
                <span class="comment_author vcard fn"><?php echo get_comment_author_link(); ?></span><br />
                <span class="comment_time"><?php echo sprintf(__('%1$s at %2$s'), get_comment_date(), get_comment_time()); ?></span>
                <span class="comment_sep"> &middot; </span>
                <span class="comment_reply"><?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?></span>
            </div>
            <div class="comment_body">
                <p><?php comment_text(); ?></p>
            </div>
		</div>
        
        
    
<?php		break;
		case 'pingback':
			break;
		case 'trackback':
			break;
	}
}
endif;

/**
 * Register widgetized areas, including 1 sidebars and four widget-ready columns in the footer.
 *
 * @uses register_sidebar
 */
function outset_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Primary Widget Area', 'outset' ),
		'id' => 'primary-widget-area',
		'description' => __( 'The primary widget area', 'outset' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
	
	if( outset_getoption("footer_widgets") == "yes" ) :
		register_sidebar( array(
			'name' => __( 'First Footer Widget Area', 'outset' ),
			'id' => 'first-footer-widget-area',
			'description' => __( 'The first footer widget area', 'outset' ),
			'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
			'after_widget' => '</li>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );
		register_sidebar( array(
			'name' => __( 'Second Footer Widget Area', 'outset' ),
			'id' => 'second-footer-widget-area',
			'description' => __( 'The second footer widget area', 'outset' ),
			'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
			'after_widget' => '</li>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );
		register_sidebar( array(
			'name' => __( 'Third Footer Widget Area', 'outset' ),
			'id' => 'third-footer-widget-area',
			'description' => __( 'The third footer widget area', 'outset' ),
			'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
			'after_widget' => '</li>',
			'before_title' => '<h3 class="widget-title">',
			'after_title' => '</h3>',
		) );
	endif;
}
/** Register sidebars by running outset_widgets_init() on the widgets_init hook. */
add_action( 'widgets_init', 'outset_widgets_init' );

/**
 * Removes the default styles that are packaged with the Recent Comments widget.
 */
function outset_remove_recent_comments_style() {
	global $wp_widget_factory;
	remove_action( 'wp_head', array( $wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style' ) );
}
add_action( 'widgets_init', 'outset_remove_recent_comments_style' );

/**
 * Prints HTML with meta information for the current post—date/time and author.
 */
function outset_posted_on(){
	printf(__('by %1$s on %2$s', 'outset'),
		sprintf('<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>',
			get_author_posts_url( get_the_author_meta( 'ID' ) ),
			sprintf( esc_attr__( 'View all posts by %s', 'outset' ), get_the_author() ),
			get_the_author()
		),
		sprintf( '<span class="entry-date"><abbr class="published" title="%1$s">%2$s</abbr></span>',
			esc_attr( get_the_time() ),
			get_the_date()
		)
	);
}

/**
 * Prints HTML with meta information for the current post (tags).
 */
function outset_posted_in(){
	$tag_list = get_the_tag_list( '', ', ' );
	if ( $tag_list ) {
		$posted_in = __( 'posted: %1$s | tagged: %2$s', 'outset' );
	} elseif ( is_object_in_taxonomy( get_post_type(), 'category' ) ) {
		$posted_in = __( 'posted: %1$s', 'outset' );
	}
	
	printf($posted_in,
		get_the_category_list( ', ' ),
		get_the_tag_list( '', ', ' )
	);
}

/**
 * Handle IE8 compatibility.
 */
if (!is_admin())
	header('X-UA-Compatible: IE=EmulateIE7');
	
/**
 * Load Theme Option.
 */
function outset_panel_init(){
	if(function_exists("add_menu_page")){
		add_theme_page( THEMENAME ." Options", THEMENAME . " Options", 'edit_themes', 'PanelOptions', 'outset_panel_options');
	}
}
add_action('admin_menu', 'outset_panel_init');
function outset_panel_options(){
	include(TEMPLATEPATH . "/library/panel/options.php");
	if ( isset($_GET['page']) && $_GET['page'] == "PanelOptions" ) {
		if ( isset($_REQUEST['action']) && "save" == $_REQUEST['action'] ) {
			foreach($options as $value){
				if(isset($value["id"])){
					$key = outset_strtoslug(THEMENAME) . "_" . $value["id"];
					if($value["type"] == "text" || $value["type"] == "textarea"){
						$data = stripslashes($_POST[$key]);
					} else {
						$data = $_POST[$key];
					}
					update_option($key, $data);
				}
			}
		} elseif( isset($_GET['action']) && "reset" == $_GET['action'] ) {
			foreach($options as $value){
				if(isset($value["id"])){
					$key = outset_strtoslug(THEMENAME) . "_" . $value["id"];
					delete_option( $key );
				}
			}
			outset_default_settings();
		}
	}
	include(TEMPLATEPATH . "/library/panel/panel.php");
}
function outset_panel_core(){
	if ('themes.php' == basename($_SERVER['SCRIPT_FILENAME'])) : ?>
	<link type="text/css" href="<?php bloginfo('template_directory'); ?>/library/panel/panel.css" rel="stylesheet" />
    <script type="text/javascript" src="<?php bloginfo('template_directory'); ?>/library/panel/js/panel.js"></script>
<?php endif;
}
add_action('admin_head', 'outset_panel_core');

/**
 * Callback To Insert Default Settings
 */
function outset_default_settings(){
	update_option(outset_strtoslug(THEMENAME) . "_homepage_title", "Your awesome homepage title here");
}

/**
 * Set Default Settings When Theme Is Activated
 */
if ( is_admin() && isset($_GET['activated'] ) && $pagenow == 'themes.php' ) {
	require_once(TEMPLATEPATH . '/library/includes/custom_functions.php');
	outset_default_settings();
}
?>